Struct wire_rs::WireWriter

source ·
pub struct WireWriter<'a, const E: bool = true> { /* private fields */ }

Implementations

Create a WireWriter that can write data types sequentially to the bytes slice.

Advance the writer’s index forward by the given amount of bytes, returning an error if there are insufficient bytes on the wire to do so.

Advance the writer’s index forward by the given number of bytes, or to the end of the wire if the amount exceeds the number of remaining bytes.

Check if the writer has no more bytes left on the wire that can be written to. If any bytes remain, return WireError::ExtraBytes; otherwise, return Ok().

Check if the writer has no more bytes left on the wire that can be written to after the given action. If any bytes remain, return WireError::ExtraBytes; otherwise, return Ok().

Check whether the writer has any remaining bytes that can be written to.

Write the given data type writable to the wire.

Write the given data type writable to L bytes on the wire.